summaryrefslogtreecommitdiff
path: root/src/include
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2017-05-08 12:44:40 +0200
committerChristian Grothoff <christian@grothoff.org>2017-05-08 12:44:40 +0200
commit5e36e520a5a9d1461cf0efaee777238a46f1890b (patch)
tree1bc5d9816bbdae9c654634ec88de25184255a26b /src/include
parent18a020dd0241fbb7deead15b96d5f5fed9f1b9b5 (diff)
downloadexchange-5e36e520a5a9d1461cf0efaee777238a46f1890b.tar.gz
exchange-5e36e520a5a9d1461cf0efaee777238a46f1890b.tar.bz2
exchange-5e36e520a5a9d1461cf0efaee777238a46f1890b.zip
updates to distinguish clearly between wtid and json transfer details
Diffstat (limited to 'src/include')
-rw-r--r--src/include/taler_exchangedb_plugin.h10
-rw-r--r--src/include/taler_wire_plugin.h2
2 files changed, 7 insertions, 5 deletions
diff --git a/src/include/taler_wire_plugin.h b/src/include/taler_wire_plugin.h
index 715f94d18..5b2bec3c0 100644
--- a/src/include/taler_wire_plugin.h
+++ b/src/include/taler_wire_plugin.h
@@ -81,11 +81,13 @@ struct TALER_WIRE_HistoryHandle;
*
* @param cls closure
* @param success #GNUNET_OK on success, #GNUNET_SYSERR on failure
+ * @param serial_id unique ID of the wire transfer in the bank's records; UINT64_MAX on error
* @param emsg NULL on success, otherwise an error message
*/
typedef void
(*TALER_WIRE_ConfirmationCallback)(void *cls,
int success,
+ uint64_t serial_id,
const char *emsg);
diff --git a/src/include/taler_exchangedb_plugin.h b/src/include/taler_exchangedb_plugin.h
index 370b114c2..a8df8c859 100644
--- a/src/include/taler_exchangedb_plugin.h
+++ b/src/include/taler_exchangedb_plugin.h
@@ -110,7 +110,7 @@ struct TALER_EXCHANGEDB_ClosingTransfer
* Detailed wire transfer information that uniquely identifies the
* wire transfer.
*/
- struct TALER_WireTransferIdentifierRawP transfer_details;
+ struct TALER_WireTransferIdentifierRawP wtid;
};
@@ -994,7 +994,7 @@ typedef int
* @param closing_fee how much did we charge for closing the reserve
* @param reserve_pub public key of the reserve
* @param receiver_account where did we send the funds
* @param transfer_details details about the wire transfer
* @return #GNUNET_OK to continue to iterate, #GNUNET_SYSERR to stop
*/
typedef int
@@ -1005,7 +1005,7 @@ typedef int
const struct TALER_Amount *closing_fee,
const struct TALER_ReservePublicKeyP *reserve_pub,
const json_t *receiver_account,
- const struct TALER_WireTransferIdentifierRawP *transfer_details);
+ const struct TALER_WireTransferIdentifierRawP *wtid);
/**
@@ -1848,7 +1848,7 @@ struct TALER_EXCHANGEDB_Plugin
* @param reserve_pub which reserve is this about?
* @param execution_date when did we perform the transfer?
* @param receiver_account to which account do we transfer?
* @param transfer_details wire transfer details
* @param amount_with_fee amount we charged to the reserve
* @param closing_fee how high is the closing fee
* @return #GNUNET_OK on success, #GNUNET_NO if the record exists,
@@ -1860,7 +1860,7 @@ struct TALER_EXCHANGEDB_Plugin
const struct TALER_ReservePublicKeyP *reserve_pub,
struct GNUNET_TIME_Absolute execution_date,
const json_t *receiver_account,
- const struct TALER_WireTransferIdentifierRawP *transfer_details,
+ const struct TALER_WireTransferIdentifierRawP *wtid,
const struct TALER_Amount *amount_with_fee,
const struct TALER_Amount *closing_fee);
@@ -994,7 +994,7 @@ typedef int
* @param reserve_pub public key of the reserve
* @param receiver_account where did we send the funds
- * @param transfer_details details about the wire transfer
+ * @param wtid identifier used for the wire transfer
* @return #GNUNET_OK to continue to iterate, #GNUNET_SYSERR to stop
*/
@@ -1848,7 +1848,7 @@ struct TALER_EXCHANGEDB_Plugin
* @param execution_date when did we perform the transfer?
* @param receiver_account to which account do we transfer?
- * @param transfer_details wire transfer details
+ * @param wtid identifier for the wire transfer
* @param amount_with_fee amount we charged to the reserve
* @param closing_fee how high is the closing fee